#
# spec file for package storeBackup
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           storeBackup
Version:        3.5.2
Release:        1.2
Summary:        A disk-to-disk backup tool for Linux
License:        GPL-3.0-or-later
Group:          Productivity/Archiving/Backup
URL:            http://storebackup.org/
Source0:        https://download.savannah.nongnu.org/releases/storebackup/storeBackup-%{version}.tar.bz2
Source1:        storeBackup-%{version}.config.default
Source2:        storeBackup-README.SUSE
Source3:        storeBackup.service
Source4:        storeBackup.timer
Source5:        storeBackup-run-all
# PATCH-FIX-UPSTREAM earlier_execute_precommand.patch http://savannah.nongnu.org/bugs/?46605
Patch0:         earlier_execute_precommand.patch
# PATCH-FIX-OPENSUSE fix-rpmlint-env-script-interpreter.patch
Patch1:         fix-rpmlint-env-script-interpreter.patch
# PATCH-FIX-UPSTREAM fix-tmp-lock-file-race-condition.patch CVE-2020-7040 bsc#1156767
Patch2:         fix-tmp-lock-file-race-condition.patch
BuildRequires:  systemd-rpm-macros
Requires:       bzip2
Requires:       e2fsprogs
Requires:       fileutils
Requires:       sh-utils
Requires:       textutils
Requires:       which
BuildArch:      noarch

%description
storeBackup is a disk-to-disk backup tool. The backuped files can be
directly browsed (locally, via NFS, via SAMBA or whatever). This
gives the users the possibility to restore files. They only have to
copy (and possibly uncompress) the file. The is also a tool for
restoring (sub) trees for the administrator. Every single backup of a
specific time can be deleted without affecting the other existing
backups.

Before you can start using storeBackup, please carefully read
        %{_docdir}/storeBackup/README.1ST
and create an appropriate configuration file
        %{_sysconfdir}/storebackup.d/storebackup.config
using
        %{_docdir}/storeBackup/storebackup.config.default
as a template.

%prep
%setup -q -n storeBackup
%patch -P 0 -p 0
%patch -P 1 -p 1
%patch -P 2 -p 1

%build
# make

%install
#
install		-d	%{buildroot}					\
			%{buildroot}%{_prefix}/lib/storeBackup/			\
			%{buildroot}%{_bindir}/				\
			%{buildroot}%{_docdir}/storeBackup/	\
			%{buildroot}%{_sysconfdir}/storebackup.d/			\
			%{buildroot}%{_sbindir}/			\
			%{buildroot}/%{_unitdir}/				\
			%{buildroot}/%{_mandir}/man1
#
cp -a %{SOURCE1}								./doc/storebackup.config.default
cp -a %{SOURCE2}								./doc/README.SUSE
cp -a _ATTENTION_ correct.sh						./doc/
cp -aRpv bin/ lib/							%{buildroot}%{_prefix}/lib/storeBackup/
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackup.pl				%{buildroot}%{_bindir}/storeBackup.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackup.pl				%{buildroot}%{_bindir}/storeBackup
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupCheckBackup.pl		%{buildroot}%{_bindir}/storeBackupCheckBackup.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupCheckSource.pl		%{buildroot}%{_bindir}/storeBackupCheckSource.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupConvertBackup.pl		%{buildroot}%{_bindir}/storeBackupConvertBackup.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupDel.pl			%{buildroot}%{_bindir}/storeBackupDel.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupMergeIsolatedBackup.pl	%{buildroot}%{_bindir}/storeBackupMergeIsolatedBackup.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupMount.pl			%{buildroot}%{_bindir}/storeBackupMount.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupRecover.pl			%{buildroot}%{_bindir}/storeBackupRecover.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupReplicationWizard.pl		%{buildroot}%{_bindir}/storeBackupReplicationWizard.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupSearch.pl			%{buildroot}%{_bindir}/storeBackupSearch.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupSetupIsolatedMode.pl		%{buildroot}%{_bindir}/storeBackupSetupIsolatedMode.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupUpdateBackup.pl		%{buildroot}%{_bindir}/storeBackupUpdateBackup.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupVersions.pl			%{buildroot}%{_bindir}/storeBackupVersions.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackupls.pl			%{buildroot}%{_bindir}/storeBackupls.pl
ln -sf %{_prefix}/lib/storeBackup/bin/storeBackup_du.pl			%{buildroot}%{_bindir}/storeBackup_du.pl
#
install -m 644 man/man1/*.1 %{buildroot}/%{_mandir}/man1
ln -sf storeBackup.pl.1 %{buildroot}/%{_mandir}/man1/storeBackup.1
install -m 644 %{SOURCE3} %{buildroot}/%{_unitdir}/%{name}.service
install -m 644 %{SOURCE4} %{buildroot}/%{_unitdir}/%{name}.timer
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
install -m 755 %{SOURCE5} %{buildroot}/%{_prefix}/lib/%{name}/%{name}-run-all
%{?suse_check}

%pre
%service_add_pre %{name}.service %{name}.timer

%post
%service_add_post %{name}.service %{name}.timer

%preun
%service_del_preun %{name}.service %{name}.timer

%postun
%service_del_postun %{name}.service %{name}.timer

%files
%doc doc/*
%{_mandir}/man1/*.1%{?ext_man}
# ChangeLog LICENSE README.1ST _ATTENTION_ README storebackup.config.default README.SUSE
%{_prefix}/lib/storeBackup/
%dir %{_sysconfdir}/storebackup.d/
%attr(755, root, root) %{_bindir}/*
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.timer

%changelog
* Sun Feb 25 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 3.5.2
    storeBackup.pl
  - option --maxHardLinks was not configurable in the
    configuration file
  - pipe buffering was changed to new needs since
    about kernel 5.13 (relevant only if you backup devices)
    storeBackupRecover.pl
  - restoring of devices (eg. sda) didn't work because of
    bug in option checkDevicesDir0 in storeBackup.pl when
    using more than one directory level like "Devs/Sticks"
    storeBackupUpdateBackup.pl
  - added log file entry about number of WARNINGs and
    ERRORs happend (like at storeBackup.pl)
- update to 3.5.1
    storeBackup.pl
  - linkToRecent didn't work when used for the very first time
    in a series
  - added option suppressInfo with key readCheckSums
  - changed the order of execution:
    write backup -> sync -> write 'finished' -> write linkToRecent
  - > delete old backups -> start postcommand
    storeBackupMergeIsolatedBackup.pl
  - added option --move
    storeBackupSearch.pl
  - option 'backupDir' didn't work (normally not needed)
    lib/fileDir.pl
  - more detailed error messages when copying of a file does
    not succeed
    lib/checkParam2.pl
  - overwriting settings from config file via commandline didn't
    work for options with parameters
    storeBackup.pl, storeBackupUpdateBackup.pl, linkToDirs.pl
  - added option --maxHardLinks
- run spec-cleaner and fixed deprecated %%patchN
* Thu Jul  8 2021 danilo.spinella@suse.com
- Improve config detection for storeBackup-run-all script
- Remove storeBackup-3.5.diff
* Wed Jul  7 2021 danilo.spinella@suse.com
- Migrate from cron to systemd timers (bsc#1115457)
  * Add a simple script to replace cron-storeBackup
* Sat Feb 22 2020 Thomas Wagner <wagner-thomas@gmx.at>
- add missing requirement to `which`
* Mon Jan 20 2020 Jan Ritzerfeld <suse@bugs.jan.ritzerfeld.org>
- add fix-tmp-lock-file-race-condition.patch:
  fix CVE-2020-7040 (bsc#1156767)
* Tue Aug 20 2019 kukuk@suse.de
- Package /etc/cron.daily, as this is now part of cron and we
  don' want to hard require cron.
* Wed Feb  6 2019 Jan Engelhardt <jengelh@inai.de>
- Remove useless -n of %%prep.
- Replace old $RPM_* shell vars.
- Ensure neutrality of description.
* Sun Mar 18 2018 suse@bugs.jan.ritzerfeld.org
- fixed location of original README.1ST in README.SUSE and spec file
* Sun Mar 18 2018 suse@bugs.jan.ritzerfeld.org
- add fix-rpmlint-env-script-interpreter.patch:
  fix rpmlint perl env-script-interpreter errors
* Mon May 29 2017 wagner-thomas@gmx.at
- don't process vim's *.swp and *.udf files (in addition to *~)
  from /etc/storebackup.d/
* Sat Dec  5 2015 wagner-thomas@gmx.at
- Added earlier_execute_precommand.patch:
  Fixed exceptDirs incomatible when mounting with precommand
  see http://savannah.nongnu.org/bugs/?46605
* Wed Aug  6 2014 wagner-thomas@gmx.at
- config file backups in /etc/storebackup.d are now ignored (bnc#855477)
* Mon Apr 21 2014 suse@bugs.jan.ritzerfeld.org
- Update to 3.5:
  * Added wildcard support to series names and option
  - -createNewSeries for replication in storeBackupUpdateBackup.pl
  * Fixed ownership and permissions of sysmlinks and their targets
    in linkToDirs.pl
  * Added option --force to storeBackupIsolatedMode.pl
  * Added options --suppressTime, --maxFilelen, --noOfOldFiles,
  - -saveLogs, and --compressWith to storeBackupMount.pl
  * Added auto-detection for cpIsGnu on Linux in storeBackup.pl
  * Fixed exit on error message "no permissions to read ..." in
    storeBackup.pl
  * Added option stayInFileSystem to storeBackup.pl
  * Renamed option --noOldFiles to --noOfOldFiles in multiTail.pl
* Mon Nov 11 2013 suse@bugs.jan.ritzerfeld.org
- Update to 3.4.3:
  * Fixed occasional copying instead of hard linking identical
    blocks in blocked files
  * Added caching of already created directories in backup when
    using --lateLinks to reduce checking whether directory does
    already exist on high latency remote line
  * Renamed multitail.pl to multiTail.pl
  * Added options --print, --color, and --grep to multiTail.pl
  * Added option --printDepth to linkToDirs.pl
  * Added time frame support to --progressReport option
    of linkToDirs.pl
* Fri Sep 27 2013 suse@bugs.jan.ritzerfeld.org
- Update to 3.4.2:
  * Fixed reading output of external programs
  * Fixed option --debug in storeBackupUpdateBackup.pl
  * Added time frame support to --progressReport option
  * Added --createSparseFiles option to storeBackupRecover.pl and
    linkToDirs.pl to create sparse files when restoring blocked
    files and copying files, respectively
* Sun Sep  8 2013 suse@bugs.jan.ritzerfeld.org
- Update to 3.4.1:
  * Fixed rule functions MARK_DIR and MARK_DIR_REC when using
    saveRAM option
  * Added chapter "Internals" to documentation
* Mon Aug 19 2013 suse@bugs.jan.ritzerfeld.org
- Update to 3.4:
  * Store "special files" in individual cpio or tar archives on
    not system compatible file systems like NTFS or sshfs,
  - -archiveTypes and --specialTypeArchiver on the command line
  * Exclude defined directories from backup or compression by file
    system flags
  * Simple recreation of isolated mode
  * Some bug fixes
* Sun Jun 16 2013 suse@bugs.jan.ritzerfeld.org
- Update to 3.3.1:
  * rewritten storeBackupMount.pl, options have changed
  * easy compression rule, --checkCompr (-C) on the command line
* Sun Mar 10 2013 suse@bugs.jan.ritzerfeld.org
- Update to 3.3:
  * Improved configurability of file compression
  * Added isolated mode/offline backups
  * Added Replication of backups
  * Added linkToDirs.pl
  * Added storeBackupCheckSource.pl
- Added "Recommends: cron" again, otherwise included automated
  backup script will not work
- Linked all storeBackup* tools to /usr/bin
- Included _ATTENTION_ and correct.sh in documentation
- Included man pages
* Mon Oct  1 2012 aj@suse.de
- Really package README.SUSE and storebackup.config.default (bnc#780664).
* Mon Jan  2 2012 cfarrell@suse.com
- license update: GPL-3.0+
  No indication of a GPL-3.0 "only" license in the package
* Thu Dec 15 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Jan  8 2010 mge@novell.com
- Update to 3.2, fixes bnc#512990
- Thanks to Lars for providing the update.
* Wed Apr  9 2008 crrodriguez@suse.de
- soft 'Recommends' cron, otherwise included automated backup
  script will not work
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 mge@suse.de
- applied patches by lenz@grimmer.com (Tue Dec 13 2005):
  [#132857]: Fixed directory permissions
  * re-added the config file to the file list
  with the proper permissions, marked as ghost
  * use more macros
* Tue Sep  6 2005 mge@suse.de
- update to 1.19 includes fixes to several smaller issues,
  and mainly these bugs:
  [#73908]:  Insecure tempfile-names
  [#73910]:  too generous permissions of backup-root
- also #100101:  Installing storeBackup causes cron job
  failure emails
  is fixed
* Fri Mar 18 2005 mge@suse.de
- this patch is (nearly) 1.19, but not final
- fixes #65788 - /etc/storebackup.d/storebackup.config should
  not be executable
- fixes #65422 - storebackup symlink attack
* Thu Aug 12 2004 mge@suse.de
- update to 1.18.4
* Mon Mar 22 2004 mge@suse.de
- update to 1.16.1: storeBackup.pl
  * better explanations in the configuration file
    and for command line options
  * better error messages
  * option --print did not work for some values
  * fixed a bug in the module for reading the
    configuration file with keepWeekday
  * when printing to a log file and to stdout
    simultaneously, a possible error message with exit
    is now also printed to stdout
  * option verbose now has the same effekt as debug=1
* Mon Mar  1 2004 mge@suse.de
- update to 1.16
* Mon Feb 23 2004 hmacht@suse.de
- building as non-root
* Mon Sep  1 2003 mge@suse.de
- update to 1.14
* Thu Aug  7 2003 mge@suse.de
- update to 1.13
* Wed Jul 30 2003 mge@suse.de
- initial checkin 1.12.2
